@@ -1,7 +1,5 @@
--- File    : hello2-8.lua
+-- File    : hello2-1.lua
 -- Purpose : Demonstration of Luerl interface.
 -- See     : ./examples/hello/hello2.erl
 
-function old() print "(33) old" end
-
-print "(32) News!"
\ No newline at end of file
+print("(6) Hello, File 'hello2-1'!")
\ No newline at end of file
