@@ -140,11 +140,11 @@ repeat_stmt(#repeat_stmt{body=B0}=R, St0) ->
 %%  The block info includes anything from the test expressions even
 %%  though we keep them separate.
 
-if_stmt(#if_stmt{tests=Ts0,else=E0}=If, St0) ->
+if_stmt(#if_stmt{tests=Ts0,else_block=E0}=If, St0) ->
     {Ts1,Tlocf,St1} = if_tests(Ts0, St0),
     {E1,Elocf,St2} = do_block(E0, St1),
     Locf = Tlocf or Elocf,
-    {If#if_stmt{tests=Ts1,else=E1},Locf,St2}.
+    {If#if_stmt{tests=Ts1,else_block=E1},Locf,St2}.
 
 if_tests([{E0,B0}|Ts0], St0) ->
     {E1,Elocf,St1} = exp(E0, St0),
