@@ -361,7 +361,7 @@ encode(nil, St) -> {nil,St};
 encode(false, St) -> {false,St};
 encode(true, St) -> {true,St};
 encode(B, St) when is_binary(B) -> {B,St};
-encode(A, St) when is_atom(A) -> {atom_to_binary(A, latin1),St};
+encode(A, St) when is_atom(A) -> {atom_to_binary(A, utf8),St};
 encode(N, St) when is_number(N) -> {N,St};      %Integers and floats
 encode(F, St) when ?IS_MAP(F) -> encode(maps:to_list(F), St);
 encode(L, St0) when is_list(L) ->
@@ -395,6 +395,12 @@ encode({M,F,A}, St) when is_atom(M) and is_atom(F) ->
     {#erl_mfa{m=M,f=F,a=A}, St};
 encode({userdata,Data}, St) ->
     luerl_heap:alloc_userdata(Data, St);
+% Table refs should not be re-encoded
+encode(#tref{}=T, St) ->
+    case luerl_heap:chk_table(T, St) of
+        ok -> {T, St};
+        error -> error(badarg)
+    end;
 encode(_, _) -> error(badarg).                  %Can't encode anything else
 
 %% decode_list([LuerlTerm], State) -> [Term].
